==> SuiteCRM-8.2.3.zip: core/backend/Install/Service/LegacyMigration/Steps/CheckLegacyConfig.php <==
<?php
/**
 * SuiteCRM is a customer relationship management program developed by SalesAgility Ltd.
 * Copyright (C) 2022 SalesAgility Ltd.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SALESAGILITY, SALESAGILITY DISCLAIMS THE
 * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License
 * version 3, these Appropriate Legal Notices must retain the display of the
 * "Supercharged by SuiteCRM" logo. If the display of the logos is not reasonably
 * feasible for technical reasons, the Appropriate Legal Notices must display
 * the words "Supercharged by SuiteCRM".
 */

namespace App\Install\Service\LegacyMigration\Steps;

use App\Engine\Model\Feedback;
use App\Engine\Model\ProcessStepTrait;
use App\Install\LegacyHandler\InstallHandler;
use App\Install\Service\Installation\InstallStatus;
use App\Install\Service\LegacyMigration\LegacyMigrationStepInterface;

/**
 * Class CheckLegacyConfig
 * @package App\Install\Service\LegacyMigration\Steps;
 */
class CheckLegacyConfig implements LegacyMigrationStepInterface
{
    use ProcessStepTrait;

    public const HANDLER_KEY = 'check-legacy-config';
    public const POSITION = 100;

    /**
     * @var InstallHandler
     */
    private $handler;

    /**
     * CheckLegacyConfig constructor.
     * @param InstallHandler $handler
     */
    public function __construct(InstallHandler $handler)
    {
        $this->handler = $handler;
    }

    /**
     * @inheritDoc
     */
    public function getKey(): string
    {
        return self::HANDLER_KEY;
    }

    /**
     * @inheritDoc
     */
    public function getOrder(): int
    {
        return self::POSITION;
    }

    /**
     * @inheritDoc
     */
    public function execute(array &$context): Feedback
    {

        $config = $this->handler->loadLegacyConfig();
        $feedback = new Feedback();
        $feedback->setSuccess(true);
        $feedback->setMessages(['Found legacy config. Proceeding with migration']);

        if ($config === null) {
            $feedback->setSuccess(false);
            $feedback->setMessages(['Legacy config not found. Stopping migration process']);
            $feedback->setStatusCode(InstallStatus::FAILED);

            return $feedback;
        }

        return $feedback;
    }

}

==> SuiteCRM-8.9.1.zip: core/backend/Install/Service/LegacyMigration/Steps/CheckLegacyConfig.php <==
<?php
/**
 * SuiteCRM is a customer relationship management program developed by SuiteCRM Ltd.
 * Copyright (C) 2022 SuiteCRM Ltd.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUITECRM, SUITECRM DISCLAIMS THE
 * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License
 * version 3, these Appropriate Legal Notices must retain the display of the
 * "Supercharged by SuiteCRM" logo. If the display of the logos is not reasonably
 * feasible for technical reasons, the Appropriate Legal Notices must display
 * the words "Supercharged by SuiteCRM".
 */

namespace App\Install\Service\LegacyMigration\Steps;

use App\Engine\Model\Feedback;
use App\Engine\Model\ProcessStepTrait;
use App\Install\LegacyHandler\InstallHandler;
use App\Install\Service\Installation\InstallStatus;
use App\Install\Service\LegacyMigration\LegacyMigrationStepInterface;

/**
 * Class CheckLegacyConfig
 * @package App\Install\Service\LegacyMigration\Steps;
 */
class CheckLegacyConfig implements LegacyMigrationStepInterface
{
    use ProcessStepTrait;

    public const HANDLER_KEY = 'check-legacy-config';
    public const POSITION = 100;

    /**
     * @var InstallHandler
     */
    private $handler;

    /**
     * CheckLegacyConfig constructor.
     * @param InstallHandler $handler
     */
    public function __construct(InstallHandler $handler)
    {
        $this->handler = $handler;
    }

    /**
     * @inheritDoc
     */
    public function getKey(): string
    {
        return self::HANDLER_KEY;
    }

    /**
     * @inheritDoc
     */
    public function getOrder(): int
    {
        return self::POSITION;
    }

    /**
     * @inheritDoc
     */
    public function execute(array &$context): Feedback
    {

        $config = $this->handler->loadLegacyConfig();
        $feedback = new Feedback();
        $feedback->setSuccess(true);
        $feedback->setMessages(['Found legacy config. Proceeding with migration']);

        if ($config === null) {
            $feedback->setSuccess(false);
            $feedback->setMessages(['Legacy config not found. Stopping migration process']);
            $feedback->setStatusCode(InstallStatus::FAILED);

            return $feedback;
        }

        return $feedback;
    }

}
